@@ -1,14 +1,10 @@
 # -*- coding: utf-8 -*-
 
-import sys
-if sys.version_info.major <= 2:
-	raise Exception("Python 2 is not supported.")
-del sys
-
 import libpwman.database
 import libpwman.dbdiff
 import libpwman.exception
 import libpwman.mlock
+import libpwman.otp
 import libpwman.ui
 import libpwman.util
 import libpwman.version
