@@ -45,6 +45,7 @@ class CryptSQLCursor:
 
 	def sqlExecScript(self, code):
 		"""Execute multiple SQL statements.
+		Warning: This implicitly commits pending transactions before executing.
 		"""
 		try:
 			self.__c.executescript(code)
@@ -146,7 +147,7 @@ class CryptSQL:
 				raise CSQLError("Invalid file header")
 			cipher = fc.getOne(b"CIPHER", "Invalid CYPHER object")
 			cipherMode = fc.getOne(b"CIPHER_MODE", "Invalid CYPHER_MODE object")
-			cipherIV = fc.getOne(b"CIPHER_IV")
+			cipherIV = fc.getOne(b"CIPHER_IV", "Invalid CIPHER_IV object")
 			keyLen = fc.getOne(b"KEY_LEN", "Invalid KEY_LEN object")
 			kdfMethod = fc.getOne(b"KDF_METHOD", "Invalid KDF_METHOD object")
 			kdfSalt = fc.getOne(b"KDF_SALT", "Invalid KDF_SALT object")
@@ -171,8 +172,6 @@ class CryptSQL:
 					cipherMode.decode("UTF-8", "ignore")))
 
 			# Check the cipher IV.
-			if not cipherIV: # legacy
-				cipherIV = b'\x00' * cipherBlockSize
 			if len(cipherIV) != cipherBlockSize:
 				raise CSQLError("Invalid IV len: %d" % len(cipherIV))
 
@@ -237,7 +236,7 @@ class CryptSQL:
 				payload = compress.decompress(payload)
 
 				# Import the SQL database.
-				self.__db.cursor().executescript(payload.decode("UTF-8"))
+				self.importSqlScript(payload.decode("UTF-8"))
 
 				# Store the raw key.
 				self.__key = key
@@ -251,7 +250,7 @@ class CryptSQL:
 	def isOpen(self):
 		"""Returns True, if a database file is opened.
 		"""
-		return bool(self.__db)
+		return self.__db is not None
 
 	def open(self, filename):
 		"""Open a database file and decrypt its contents into memory.
@@ -266,8 +265,7 @@ class CryptSQL:
 		try:
 			self.__parseFile(filename)
 		except CSQLError as e:
-			self.__db = None
-			self.__filename = None
+			self.close()
 			raise e
 		self.__filename = filename
 
@@ -406,6 +404,7 @@ class CryptSQL:
 
 	def sqlExecScript(self, code):
 		"""Execute multiple SQL statements.
+		Warning: This implicitly commits pending transactions before executing.
 		"""
 		return CryptSQLCursor(self.__db).sqlExecScript(code)
 
