@@ -205,16 +205,21 @@ class PWManDatabase(CryptSQL):
 	def __garbageCollect(self):
 		"""Remove rows from the SQL database that are not needed anymore.
 		"""
-		c = self.sqlExecScript("""
-			DELETE FROM bulk WHERE entry NOT IN (SELECT id FROM entries);
-			DELETE FROM entryattr WHERE entry NOT IN (SELECT id FROM entries);
-			DELETE FROM totp WHERE entry NOT IN (SELECT id FROM entries);
-		""")
+		# Do not use sqlExecScript here, as that would commit transactions.
+		c = self.sqlExec("DELETE FROM bulk WHERE entry NOT IN (SELECT id FROM entries);")
+		c = self.sqlExec("DELETE FROM entryattr WHERE entry NOT IN (SELECT id FROM entries);")
+		c = self.sqlExec("DELETE FROM totp WHERE entry NOT IN (SELECT id FROM entries);")
 
 	def setPassphrase(self, passphrase):
 		super().setPassphrase(passphrase)
 		self.__setDirty()
 
+	def categoryExists(self, category):
+		"""Returns True, if a category exists in the database.
+		category: The name string of the category.
+		"""
+		return category in self.getCategoryNames()
+
 	def getCategoryNames(self):
 		"""Get all category names in the database.
 		Returns a sorted list of strings.
@@ -238,22 +243,6 @@ class PWManDatabase(CryptSQL):
 		titles = sorted(t[0] for t in titles)
 		return titles
 
-	def renameCategory(self, category, toCategory):
-		"""Change the name of a category.
-		category: The old name string of the category.
-		toCategory: The new name string of the category.
-		"""
-		categories = self.getCategoryNames()
-		if category not in categories:
-			raise PWManError("Source category does not exist.")
-		if toCategory in categories:
-			raise PWManError("Target category does already exist.")
-		c = self.sqlExec("UPDATE entries SET category=? "
-				 "WHERE category=?;",
-				 (toCategory,
-				  category))
-		self.__setDirty()
-
 	def getEntry(self, category, title):
 		"""Get an entry from the database.
 		category: The name string of the category to get an entry from.
@@ -401,7 +390,7 @@ class PWManDatabase(CryptSQL):
 		category: The name string of the category.
 		title: The title string of the entry.
 		"""
-		return bool(self.getEntry(category, title))
+		return self.getEntry(category, title) is not None
 
 	def addEntry(self, entry):
 		"""Create a new entry in the database.
@@ -463,6 +452,19 @@ class PWManDatabase(CryptSQL):
 				  oldEntry.entryId))
 		self.__setDirty()
 
+	def moveEntries(self, fromCategory, toCategory):
+		"""Move all entries from one category to another category.
+		fromCategory: The category to move all entries from.
+		toCategory: The (new) category to move all entries to.
+		"""
+		if not self.categoryExists(fromCategory):
+			raise PWManError("Source category does not exist.")
+		c = self.sqlExec("UPDATE entries SET category=? "
+				 "WHERE category=?;",
+				 (toCategory,
+				  fromCategory))
+		self.__setDirty()
+
 	def delEntry(self, entry):
 		"""Delete an existing entry from the database.
 		entry: The PWManEntry() instance to delete from the database.
