@@ -1,24 +1,8 @@
 # -*- coding: utf-8 -*-
 """
-#
 # mlock support
-#
-# Copyright 2019-2020 Michael Buesch <m@bues.ch>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
+# Copyright (c) 2019-2023 Michael Büsch <m@bues.ch>
+# Licensed under the GNU/GPL version 2 or later.
 """
 
 import platform
@@ -29,7 +13,7 @@ __all__ = [
 	"MLockWrapper",
 ]
 
-class MLockWrapper(object):
+class MLockWrapper:
 	"""OS mlock wrapper.
 	"""
 
